+++
title = "Setting heading anchors"
date = 2017-07-12T17:05:39-04:00
draft = false
+++

## Heading 1 of the post {#cool-ref-1}

Something


### Heading 1.1 of the post {#cool-ref-1.1}

Something else


## Heading 2 of the post {#cool-ref-2}

Something 2


### Heading 2.1 of the post {#cool-ref-2.1}

Something 2.1
